@@ -252,6 +252,7 @@ def train(model, train_iter, dev_iter, num_epochs=10, learning_rate=1e-3, requir
                 dev_acc, dev_loss = evaluate(model, dev_iter)
                 if dev_loss < dev_best_loss:
                     dev_best_loss = dev_loss
+                    model.eval()
                     torch.save(model.state_dict(), save_path)
                     logger.debug(f'Saved model: {save_path}')
                     improve = '*'
@@ -306,10 +307,11 @@ def predict(model, data_list, word_id_map, label_id_map):
     with torch.no_grad():
         for texts, _ in data_iter:
             outputs = model(texts)
-            pred = torch.max(outputs, 1)[1].detach().cpu().numpy()
+            logit = F.softmax(outputs, dim=1).detach().cpu().numpy()
+            pred = np.argmax(logit, axis=1)
+            proba = np.max(logit, axis=1)
+
             predict_all = np.append(predict_all, pred)
-            log_proba = torch.max(outputs, 1)[0].detach().cpu().numpy()
-            proba = 1 - np.exp(-log_proba)
             proba_all = np.append(proba_all, proba)
     id_label_map = {v: k for k, v in label_id_map.items()}
     predict_label = [id_label_map.get(i) for i in predict_all]
@@ -362,9 +364,8 @@ if __name__ == '__main__':
     for text, label, proba in zip(X[:10], predict_label, predict_proba):
         print(text, label, proba)
     # load new model and predict
-    model = TextRNNAttModel(vocab_size, num_classes).to(device)
-    init_network(model)
-    new_model = load_model(model, save_model_path)
+    new_model = TextRNNAttModel(vocab_size, num_classes).to(device)
+    new_model = load_model(new_model, save_model_path)
     print('new model loaded from file, and predict')
     predict_label, predict_proba = predict(new_model, X[:10], word_id_map, label_id_map)
     for text, label, proba in zip(X[:10], predict_label, predict_proba):
